FeedConfig class
SDK configuration provided by the host app.
Constructors
Properties
- apiKey → String
-
API key or token used by the backend.
final
- baseUrl → String
-
Base URL for the feed backend, e.g.
https://api.example.com.final -
defaultHeaders
→ Map<
String, String> -
Optional additional headers to include with every request.
final
- feedEndpointPath → String
-
Path used to fetch the feed from baseUrl, e.g.
/v1/feed.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited